Struct comfy::wgpu::BindGroup

pub struct BindGroup { /* private fields */ }
Handle to a binding group.

A BindGroup represents the set of resources bound to the bindings described by a BindGroupLayout. It can be created with Device::create_bind_group. A BindGroup can be bound to a particular RenderPass with RenderPass::set_bind_group, or to a ComputePass with ComputePass::set_bind_group.

Corresponds to WebGPU GPUBindGroup.

Implementations



impl BindGroup

pub fn global_id(&self) -> Id<BindGroup>

Returns a globally-unique identifier for this BindGroup.

Calling this method multiple times on the same object will always return the same value. The returned value is guaranteed to be unique among all BindGroups created from the same Instance.